=========================
 Invenio-XRootD v1.0.0a1
=========================

Invenio-XRootD v1.0.0a1 was released on August 19, 2016.

About
-----

XRootD file storage support for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-xrootd==1.0.0a1

Documentation
-------------

   http://pythonhosted.org/invenio-xrootd/

Happy hacking and thanks for flying Invenio-XRootD.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-xrootd
|   URL: http://inveniosoftware.org
